==> haskell-serialise-0.2.6.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-serialise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 serialise
version:              0.2.6.1
visibility:           public
id:                   serialise-0.2.6.1-FGRRc0lYNGgRaOlveOzSU
key:                  serialise-0.2.6.1-FGRRc0lYNGgRaOlveOzSU
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A binary serialisation library for Haskell values.
description:
    This package (formerly @binary-serialise-cbor@) provides pure, efficient
    serialization of Haskell values directly into @ByteString@s for storage or
    transmission purposes. By providing a set of type class instances, you can
    also serialise any custom data type you have as well.

    The underlying binary format used is the '\''Concise Binary Object
    Representation'\'', or CBOR, specified in RFC 7049. As a result,
    serialised Haskell values have implicit structure outside of the
    Haskell program itself, meaning they can be inspected or analyzed
    without custom tools.

    An implementation of the standard bijection between CBOR and JSON is provided
    by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility for
    working with CBOR data.

category:             Codec
abi:                  3f52f28d3a6ec4d223d09799f87b9353
exposed:              True
exposed-modules:
    Codec.Serialise Codec.Serialise.Class Codec.Serialise.Decoding
    Codec.Serialise.Encoding Codec.Serialise.IO
    Codec.Serialise.Internal.GeneralisedUTF8 Codec.Serialise.Properties
    Codec.Serialise.Tutorial

import-dirs:          /usr/lib/ghc-9.2.8/site-local/serialise-0.2.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/serialise-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-serialise
hs-libraries:         HSserialise-0.2.6.1-FGRRc0lYNGgRaOlveOzSU
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0
    cborg-0.2.9.0-Hoj94TrRtxznrQPLIYBlw containers-0.6.5.1
    ghc-prim-0.8.0 half-0.3.2-6DADbogMlwWIsPAlkMxc30
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb
    primitive-0.7.4.0-2yvrjkKbYif9hwxczpmLrN
    strict-0.5-BpTWLv1xxwX5Hi4tj95CxE text-1.2.5.0
    these-1.2-8ldZVecV38vAFRpqQwBo5Z time-1.11.1.1
    unordered-containers-0.2.20-DtI6Ump4gwL4XOoZ2vYwmp
    vector-0.13.1.0-fp7g3DnwvJ21p5JSIbLxP

haddock-interfaces:   /usr/share/doc/haskell-serialise/html/serialise.haddock
haddock-html:         /usr/share/doc/haskell-serialise/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-serialise-0.2.6.1-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-serialise.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 serialise
version:              0.2.6.1
visibility:           public
id:                   serialise-0.2.6.1-8xZuBLbEa28B6PlCZtJRv0
key:                  serialise-0.2.6.1-8xZuBLbEa28B6PlCZtJRv0
license:              BSD-3-Clause
copyright:
    2015-2017 Duncan Coutts,
    2015-2017 Well-Typed LLP,
    2015 IRIS Connect Ltd

maintainer:           duncan@community.haskell.org, ben@smart-cactus.org
author:               Duncan Coutts
homepage:             https://github.com/well-typed/cborg
synopsis:             A binary serialisation library for Haskell values.
description:
    This package (formerly @binary-serialise-cbor@) provides pure, efficient
    serialization of Haskell values directly into @ByteString@s for storage or
    transmission purposes. By providing a set of type class instances, you can
    also serialise any custom data type you have as well.

    The underlying binary format used is the '\''Concise Binary Object
    Representation'\'', or CBOR, specified in RFC 7049. As a result,
    serialised Haskell values have implicit structure outside of the
    Haskell program itself, meaning they can be inspected or analyzed
    without custom tools.

    An implementation of the standard bijection between CBOR and JSON is provided
    by the [cborg-json](/package/cborg-json) package. Also see
    [cbor-tool](/package/cbor-tool) for a convenient command-line utility for
    working with CBOR data.

category:             Codec
abi:                  5dbbd0d986fb10b66812227984878c2b
exposed:              True
exposed-modules:
    Codec.Serialise Codec.Serialise.Class Codec.Serialise.Decoding
    Codec.Serialise.Encoding Codec.Serialise.IO
    Codec.Serialise.Internal.GeneralisedUTF8 Codec.Serialise.Properties
    Codec.Serialise.Tutorial

import-dirs:          /usr/lib/ghc-9.2.8/site-local/serialise-0.2.6.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/serialise-0.2.6.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-serialise
hs-libraries:         HSserialise-0.2.6.1-8xZuBLbEa28B6PlCZtJRv0
depends:
    array-0.5.4.0 base-4.16.4.0 bytestring-0.11.4.0
    cborg-0.2.9.0-7iRJhnEF3OSdP9cIzUrRK containers-0.6.5.1
    ghc-prim-0.8.0 half-0.3.2-JUgnt1UEDGDJxylpbXsWPk
    hashable-1.4.4.0-EsPTAmPpYqX3hovcHlHOLX
    primitive-0.7.4.0-6KmKRdtjMquLpK2leC8DMp
    strict-0.5-I1QlvpN8R7x80TzoNfS6Q7 text-1.2.5.0
    these-1.2-JSDM0V4jeC67wQ6jFiVXg time-1.11.1.1
    unordered-containers-0.2.20-3olzmtJszxXc2LJr1lW5F
    vector-0.13.1.0-IOwb1qSGKSdHIyg7Qp7MNu

haddock-interfaces:   /usr/share/doc/haskell-serialise/html/serialise.haddock
haddock-html:         /usr/share/doc/haskell-serialise/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
